pub struct DependencyChange {
pub name: String,
pub old_version: Option<String>,
pub new_version: Option<String>,
pub change_type: DependencyChangeType,
}Expand description
Information about a dependency change.
Fields
name: Stringold_version: Option<String>new_version: Option<String>change_type: DependencyChangeTypeTrait Implementations
Sourceimpl Clone for DependencyChange
impl Clone for DependencyChange
Sourcefn clone(&self) -> DependencyChange
fn clone(&self) -> DependencyChange
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DependencyChange
impl Debug for DependencyChange
Sourceimpl<'de> Deserialize<'de> for DependencyChange
impl<'de> Deserialize<'de> for DependencyChange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DependencyChange
impl JsonSchema for DependencyChange
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DependencyChange
impl PartialEq for DependencyChange
Sourceimpl Serialize for DependencyChange
impl Serialize for DependencyChange
impl Eq for DependencyChange
impl StructuralPartialEq for DependencyChange